'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports.findSiblingsWithFileExtension = exports.enhanceUnexpectedTokenMessage = undefined;

var _path;

function _load_path() {
  return (_path = _interopRequireDefault(require('path')));
}

var _chalk;

function _load_chalk() {
  return (_chalk = _interopRequireDefault(require('chalk')));
}

var _slash;

function _load_slash() {
  return (_slash = _interopRequireDefault(require('slash')));
}

var _glob;

function _load_glob() {
  return (_glob = _interopRequireDefault(require('glob')));
}

function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : {default: obj};
}

const DOT = ' \u2022 '; // Copyright (c) 2014-present, Facebook, Inc. All rights reserved.

const enhanceUnexpectedTokenMessage = (exports.enhanceUnexpectedTokenMessage = e => {
  e.stack =
    `${(_chalk || _load_chalk()).default.bold.red(
      'Jest encountered an unexpected token'
    )}

This usually means that you are trying to import a file which Jest cannot parse, e.g. it's not plain JavaScript.

By default, if Jest sees a Babel config, it will use that to transform your files, ignoring "node_modules".

Here's what you can do:
${DOT}To have some of your "node_modules" files transformed, you can specify a custom ${(
      _chalk || _load_chalk()
    ).default.bold('"transformIgnorePatterns"')} in your config.
${DOT}If you need a custom transformation specify a ${(
      _chalk || _load_chalk()
    ).default.bold('"transform"')} option in your config.
${DOT}If you simply want to mock your non-JS modules (e.g. binary assets) you can stub them out with the ${(
      _chalk || _load_chalk()
    ).default.bold('"moduleNameMapper"')} config option.

You'll find more details and examples of these config options in the docs:
${(_chalk || _load_chalk()).default.cyan(
      'https://jestjs.io/docs/en/configuration.html'
    )}

${(_chalk || _load_chalk()).default.bold.red('Details:')}

` + e.stack;

  return e;
});

const findSiblingsWithFileExtension = (exports.findSiblingsWithFileExtension = (
  moduleFileExtensions,
  from,
  moduleName
) => {
  if (
    !(_path || _load_path()).default.isAbsolute(moduleName) &&
    (_path || _load_path()).default.extname(moduleName) === ''
  ) {
    const dirname = (_path || _load_path()).default.dirname(from);
    const pathToModule = (_path || _load_path()).default.resolve(
      dirname,
      moduleName
    );

    try {
      const slashedDirname = (0, (_slash || _load_slash()).default)(dirname);

      const matches = (_glob || _load_glob()).default
        .sync(`${pathToModule}.*`)
        .map(match => (0, (_slash || _load_slash()).default)(match))
        .map(match => {
          const relativePath = (_path || _load_path()).default.posix.relative(
            slashedDirname,
            match
          );

          return (_path || _load_path()).default.posix.dirname(match) ===
            slashedDirname
            ? `./${relativePath}`
            : relativePath;
        })
        .map(match => `\t'${match}'`)
        .join('\n');

      if (matches) {
        const foundMessage = `\n\nHowever, Jest was able to find:\n${matches}`;

        const mappedModuleFileExtensions = moduleFileExtensions
          .map(ext => `'${ext}'`)
          .join(', ');

        return (
          foundMessage +
          "\n\nYou might want to include a file extension in your import, or update your 'moduleFileExtensions', which is currently " +
          `[${mappedModuleFileExtensions}].\n\nSee https://jestjs.io/docs/en/configuration#modulefileextensions-array-string`
        );
      }
    } catch (ignored) {}
  }

  return '';
});
